/*
 * (C) Copyright IBM Corporation 2014, 2016.
 * (C) Copyright HCL Technologies Limited 2016, 2017.
*/
/*
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA

 Author: IBM Corporation and/or HCL Technologies Ltd.
 This module is part of the IBM (R) Rational (R) ClearCase (R)(*)
 Multi-version file system (MVFS).
 For support, please visit http://www.ibm.com/software/support

 * ClearCase is a trademark of IBM Corporation, registered in many
   jurisdictions, and is used under license.
*/
#ifndef _MVFS_LPC_MDEP_H_
#define _MVFS_LPC_MDEP_H_

#include "mvfs_lpc_linux.h"

/* int
 * MVFS_LPC_MDEP_INITIALIZE(void)
 *
 * Initializes the machine dependent LPC subsystem.
 *
 * Inputs:
 * None
 *
 * Return:
 * 0 on success, errno otherwise.
 */
#ifndef MVFS_LPC_MDEP_INITIALIZE
#error "MVFS_LPC_MDEP_INITIALIZE undefined. Please define in LPC mdep header."
#endif

/* int
 * MVFS_LPC_MDEP_TEARDOWN(void)
 *
 * Tearsdown the machine dependent LPC subsystem.
 *
 * Inputs:
 * None
 *
 * Return:
 * 0 on success, errno otherwise.
 */
#ifndef MVFS_LPC_MDEP_TEARDOWN
#error "MVFS_LPC_MDEP_TEARDOWN undefined. Please define in LPC mdep header."
#endif

/* int
 * MVFS_LPC_MDEP_DESTROY(
 *     MVFS_LPC_MDEP_H_T h
 * );
 *
 * This function is called once all kernel space references to the given handle
 * are gone and indicates that the given handle should be destroyed along with
 * all of the resources allocated to it.
 *
 * Inputs:
 * h - Specifies the machine dependent handle to be destroyed.
 *
 * Return:
 * Unused. This function must not fail to deallocate any resources associated
 * with this handle. 
 */
#ifndef MVFS_LPC_MDEP_DESTROY
#error "MVFS_LPC_MDEP_DESTROY undefined. Please define in LPC mdep header."
#endif

/* int
 * MVFS_LPC_MDEP_CREATE(
 *    const char *nm,
 *    CRED_T *cred,
 *    MVFS_LPC_MDEP_H_T *hp
 * );
 *
 * Creates a new LPC endpoint with the given identfier.
 *
 * Inputs:
 * nm - A string containing the LPC identifier.
 * cred - A pointer to a CRED_T specifying the owner (user space) of this
 *        endpoint. A NULL pointer indicates that anyone should be allowed to
 *        access the endpoint from user space.
 * hp - A pointer to a machine dependent handle type to be filled in with the
 *      newly created handle.
 */
#ifndef MVFS_LPC_MDEP_CREATE
#error "MVFS_LPC_MDEP_CREATE undefined. Please define in LPC mdep header."
#endif

/* int
 * MVFS_LPC_MDEP_FLUSH(
 *     MVFS_LPC_MDEP_H_T h
 * );
 *
 * This function is called by mfs_viewdirrmdir, usually as part of a
 * MVFS_CMD_RMVIEWTAG ioctl.  It should do any machine dependent work needed
 * before mvfs_lpc_destroy is called to actually destroy the handle.  For
 * instance, this might clear lists of waiting threads defined by the handle.
 *
 * Inputs:
 * h - Specifies the machine dependent handle to be flushed.
 *
 * Return:
 * 0 on success, errno otherwise.
 */
#ifndef MVFS_LPC_MDEP_FLUSH
#error "MVFS_LPC_MDEP_FLUSH undefined. Please define in LPC mdep header."
#endif

/* enum clnt_stat
 * MVFS_LPC_MDEP_CALL(
 *     MVFS_LPC_MDEP_HANDLE_T h,
 *     int op,
 *     u_long timeout,
 *     void *input_buffer,
 *     u_long input_buffer_size,
 *     void *output_buffer,
 *     u_long output_buffer_size
 * );
 *
 * Makes an LPC call using the endpoint associated with the given handle.
 *
 * Inputs:
 * h - A machine dependent handle that indicates the endpoint that the call
 *     should be made on.
 * op - Specifies the LPC operation number.
 * timeout - Specifies the timeout length in tenths of a second. Zero indicates
 *           no timeout.
 * input_buffer - A pointer to the LPC request data.
 * input_buffer_size - The size of the LPC request data in bytes.
 * output_buffer - A pointer to where the LPC response data should be stored.
 * output_buffer_size - The size of the LPC response data buffer in bytes.
 *
 * Return:
 * RPC_SUCCESS on success, one of the error codes from the clnt_stat enum
 * otherwise.
 */
#ifndef MVFS_LPC_MDEP_CALL
#error "MVFS_LPC_MDEP_CALL undefined. Please define in LPC mdep header."
#endif

/* Defines a machine dependent LPC handle type. */
#ifndef MVFS_LPC_MDEP_H_T
#error "MVFS_LPC_MDEP_H_T undefined. Please define in LPC mdep header."
#endif

#endif
/* $Id: a6b4bd12.bf2911e7.8732.44:37:e6:71:22:3b $ */
